@@ -10,7 +10,8 @@ from .dto.user.notification import UserNotification
 from .dto.user.state import UserState
 from .dto.user.store import UserStore
 from .dto.user.user import User
-from .feature_details import FeatureDetails
-from .feature_type import FeatureType
-from .store_type import StoreType
-from .user_event_other_type import UserEventOtherType
+from .types.feature_detail_type import FeatureDetailType
+from .types.feature_type import FeatureType
+from .types.income_source_type import IncomeSourceType
+from .types.store_type import StoreType
+from .types.user_event_other_type import UserEventOtherType
